@@ -69,11 +69,17 @@ def sendmsg(usr, msg, path='error', attach='error'):
                     image_box.send_keys(attach)
                     time.sleep(1)
 
-                    text_box = browser.find_element("xpath", '//div[@data-testid="media-caption-input-container"][@role="textbox"]')
+                    send_btn_xpath = '//span[@data-testid="send"][@data-icon="send"]'
+                    send_btn = browser.find_element('xpath', send_btn_xpath)
+                    send_btn.click()
+                    time.sleep(1)
+
+                    msgbox_xpath = '//div[@title="Type a message"][@role="textbox"]'
+                    msgbox = browser.find_element('xpath', msgbox_xpath)
                     pyperclip.copy(mssg)
-                    text_box.send_keys(Keys.SHIFT, Keys.INSERT)
+                    msgbox.send_keys(Keys.SHIFT, Keys.INSERT)
                     time.sleep(2)
-                    text_box.send_keys(Keys.ENTER)
+                    msgbox.send_keys(Keys.ENTER)
                     time.sleep(2)
 
                 else:
